import bpy # type: ignore
from pathlib import Path
from .download import download_zip
from pathlib import Path


down_path = Path(__file__).parent
cwd_name = down_path.name
id = cwd_name.lower()
xz_url = "assets_browser" + "/"
assets_name = id + "_lib"
download_zip(xz_url + f"{assets_name}.zip", down_path)

def remove_assets_item(assets_name):
    asset_libraries = bpy.context.preferences.filepaths.asset_libraries
    try:
        asset_libraries.remove(asset_libraries[assets_name])
    except:
        print(f"无法移除 '{assets_name}' 资源库,请检查该名称!")
        

class ADD_To_Assets_Browser(bpy.types.Operator):
    bl_idname = f"add2_assets_browser.{id}"
    bl_label = cwd_name
    bl_description = "添加资源到资产管理器中"
    bl_options = {"REGISTER"}
    
    remove: bpy.props.BoolProperty(default=False) # type: ignore

    @classmethod
    def poll(cls, context):
        return True
    def change_assets_library_path(self,remove=False):
        asset_libraries = bpy.context.preferences.filepaths.asset_libraries
        names = asset_libraries.keys()
        as_path = str(down_path / assets_name)
        if assets_name not in names and not remove:
            bpy.ops.preferences.asset_library_add(directory=as_path)
            asset_libraries[-1].name = assets_name
            self.report({ "INFO" }, f"已添加 '{assets_name}' 到资产库中!")
        elif assets_name in names and not remove:
            asset_libraries[assets_name].path = as_path
            self.report({ "INFO" }, f"资产库 '{assets_name}' 已存在!")
        elif remove:
            remove_assets_item(assets_name)
            self.report({ "INFO" }, f"已从资产库中移除 '{assets_name}' !")
    def execute(self, context):
        self.change_assets_library_path(self.remove)
        return {"FINISHED"}
def add_assets():
    getattr(bpy.ops.add2_assets_browser, id)(False)

    
class ADD_To_Assets_Browser_Preferences(bpy.types.AddonPreferences):
    bl_idname = __package__
    
    def draw(self, context):
        layout = self.layout
        row = layout.row()
        row.operator(ADD_To_Assets_Browser.bl_idname, text="添加到资产库中", icon="ADD")
        row.operator(ADD_To_Assets_Browser.bl_idname, text="从资产库中移除", icon="X").remove = True


CLASSES = [
    ADD_To_Assets_Browser,
    ADD_To_Assets_Browser_Preferences,
]
register_class,unregister_class = bpy.utils.register_classes_factory(CLASSES)

def register():
    register_class()
    bpy.app.timers.register(add_assets)
def unregister():
    remove_assets_item(assets_name)
    unregister_class()


if __name__ == "__main__":
    register()
